# Wheel tire

## License

Adapted from [Car Rim Collection Set 4](https://www.thingiverse.com/thing:3014733) by bramesh501 (July 22, 2018) which is licensed under the [Creative Commons - Attribution](https://creativecommons.org/licenses/by/4.0/) license.

## Changes

- Combined ``Rim_13.STL`` and ``Tyre_model_1.STL``.
- Scale them so that the outer diameter is 100 mm.
